==> genwall_1.0.4.tar.gz: genwall-1.0.4/mainwindow.h <==
#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QModelIndex>

namespace Ui
{
class MainWindow;
}
class RCQTextEdit;
class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit MainWindow(QWidget *parent = 0);
    //QAction *newAct2;
    ~MainWindow();


private:
    Ui::MainWindow *ui;
protected:
    void closeEvent(QCloseEvent *event);

private slots:
    void save_ini();
    void load_ini();
    void wload_ini();
    void checkbootfile();
    void on_pushButton_rulenow_clicked();
    void on_listWidget_real_doubleClicked(QModelIndex index);
    int runtime_filter(QString);
    void refresh_filter();
    void on_pushButton_showresolv_clicked();
    void on_pushButton_adddns_clicked();
    void on_pushButton_routedefaultadd_clicked();
    void on_pushButton_gweadd_clicked();
    void on_pushButton_ruledropall_clicked();
    void on_checkBox_outloop_clicked(bool checked);
    void on_pushButton_outportclear_clicked();
    void on_pushButton_outportsave_clicked();
    void on_pushButton_outportrm_clicked();
    void on_pushButton_outportload_clicked();
    void on_pushButton_outportadd_clicked();
    void on_checkBox_output_clicked(bool checked);
    void on_pushButton_optmore_clicked();
    void on_pushButton_outportmore_clicked();
    void on_tabWidget_for_currentChanged(int index);
    void on_tabWidget_local_currentChanged(int index);
    void on_checkBox_icmp_stateChanged(int );
    void on_checkBox_filteroutput_stateChanged(int );
    void on_pushButton_rulefire_clicked();
    void on_pushButton_ruledrop_clicked();
    void on_pushButton_goextra_clicked();
    void on_pushButton_gomain_clicked();
    void on_pushButton_ruleaccept_clicked();
    void on_listWidget_log_doubleClicked(QModelIndex index);
    void getcontext_signal(int);
    void on_pushButton_stopklogd_clicked();
    void on_pushButton_startklogd_clicked();
    void on_pushButton_rmsyslog_clicked();
    void on_pushButton_stopsysd_clicked();
    void on_pushButton_startsysd_clicked();
    void on_pushButton_loadlog_clicked();
    void on_tabWidget_rules_currentChanged(int index);
    void on_pushButton_clearfport_clicked();
    void on_pushButton_loportclear_clicked();
    void on_pushButton_clearrules_clicked();
    void on_pushButton_loadrules_clicked();
    void on_pushButton_saverules_clicked();
    void on_pushButton_editrule_clicked();
    void on_pushButton_rmrule_clicked();
    void on_pushButton_addrule_clicked();
    void on_pushButton_loadfport_clicked();
    void on_pushButton_savefport_clicked();
    void on_pushButton_loadloport_clicked();
    void on_pushButton_saveloport_clicked();
    void checkwmode();
    void wifistatus();
    bool checkmodule(QString nmodule);
    int cuttercount(QString row);
    int cutterint(QString row, int place);
    QString getBTproperty(QString key);
    QString getBTname();
    QString getBTdevPath();
    QString getlsof();
    QString write_filter(QString);
    QString filterlog(QString linelog);
    QString cutter(QString row, QString cutstr, int place);
    QString getip(QString dev);
    bool wmode(QString dev);
    QString getfilter(QString ftype);
    QString getpidof(QString pname);
    void sshstatus();
    void getrev();
    void getimei();
    void getimsi();
    void getpower();
    void getos();
    void getkernel();
    void deleteSettings(QString);
    void on_tabWidget_route_currentChanged(int index);
    void on_pushButton_ipinfo_clicked();
    void on_checkBox_sship_clicked(bool checked);
    void on_radioButton_masqlan_clicked(bool checked);
    void on_radioButton_masqsub_clicked(bool checked);
    void on_checkBox_forward_stateChanged(int );
    void on_pushButton_rmfport_clicked();
    void on_pushButton_addfport_clicked();
    void on_pushButton_loportdel_clicked();
    void on_pushButton_addloport_clicked();
    void on_pushButton_gen_clicked();
    void on_pushButton_stop_clicked();
    void on_pushButton_start_clicked();
    void write_wall();
    void on_pushButton_loaddnow_clicked();
    void on_pushButton_saveini_clicked();
    void on_pushButton_loadini_clicked();
    void on_pushButton_deleteset_clicked();
    void on_pushButton_gwdel_clicked();
    void on_pushButton_routedefaultdel_clicked();
    void on_pushButton_resetdns_clicked();
    void on_pushButton_wsave_clicked();
    void on_pushButton_wstartstop_clicked();
    void on_pushButton_wadhoc_clicked();
    void on_pushButton_sshstartstop_clicked();
    void on_pushButton_btsave_clicked();
    void on_pushButton_btonoff_clicked();
    void on_pushButton_btstartstop_clicked();
    void on_pushButton_delboot_clicked();
};

#endif // MAINWINDOW_H

==> genwall_1.0.6.tar.gz: genwall-1.0.6/mainwindow.h <==
#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QModelIndex>

namespace Ui
{
class MainWindow;
}
class RCQTextEdit;
class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit MainWindow(QWidget *parent = 0);
    //QAction *newAct2;
    ~MainWindow();


private:
    Ui::MainWindow *ui;
protected:
    void closeEvent(QCloseEvent *event);

private slots:
    void save_ini();
    void load_ini();
    void wload_ini();
    void checkbootfile();
    void on_pushButton_rulenow_clicked();
    void on_listWidget_real_doubleClicked(QModelIndex index);
    int runtime_filter(QString);
    void refresh_filter();
    void on_pushButton_showresolv_clicked();
    void on_pushButton_adddns_clicked();
    void on_pushButton_routedefaultadd_clicked();
    void on_pushButton_gweadd_clicked();
    void on_pushButton_ruledropall_clicked();
    void on_checkBox_outloop_clicked(bool checked);
    void on_pushButton_outportclear_clicked();
    void on_pushButton_outportsave_clicked();
    void on_pushButton_outportrm_clicked();
    void on_pushButton_outportload_clicked();
    void on_pushButton_outportadd_clicked();
    void on_checkBox_output_clicked(bool checked);
    void on_pushButton_optmore_clicked();
    void on_pushButton_outportmore_clicked();
    void on_tabWidget_for_currentChanged(int index);
    void on_tabWidget_local_currentChanged(int index);
    void on_checkBox_icmp_stateChanged(int );
    void on_checkBox_filteroutput_stateChanged(int );
    void on_pushButton_rulefire_clicked();
    void on_pushButton_ruledrop_clicked();
    void on_pushButton_goextra_clicked();
    void on_pushButton_gomain_clicked();
    void on_pushButton_ruleaccept_clicked();
    void on_listWidget_log_doubleClicked(QModelIndex index);
    void getcontext_signal(int);
    void on_pushButton_stopklogd_clicked();
    void on_pushButton_startklogd_clicked();
    void on_pushButton_rmsyslog_clicked();
    void on_pushButton_stopsysd_clicked();
    void on_pushButton_startsysd_clicked();
    void on_pushButton_loadlog_clicked();
    void on_tabWidget_rules_currentChanged(int index);
    void on_pushButton_clearfport_clicked();
    void on_pushButton_loportclear_clicked();
    void on_pushButton_clearrules_clicked();
    void on_pushButton_loadrules_clicked();
    void on_pushButton_saverules_clicked();
    void on_pushButton_editrule_clicked();
    void on_pushButton_rmrule_clicked();
    void on_pushButton_addrule_clicked();
    void on_pushButton_loadfport_clicked();
    void on_pushButton_savefport_clicked();
    void on_pushButton_loadloport_clicked();
    void on_pushButton_saveloport_clicked();
    void checkwmode();
    void wifistatus();
    bool checkmodule(QString nmodule);
    bool checkdnsmasq();
    int cuttercount(QString row);
    int cutterint(QString row, int place);
    QString getBTproperty(QString key);
    QString getBTname();
    QString getBTdevPath();
    QString getlsof();
    QString write_filter(QString);
    QString filterlog(QString linelog);
    QString cutter(QString row, QString cutstr, int place);
    QString getip(QString dev);
    bool wmode(QString dev);
    QString getfilter(QString ftype);
    QString getpidof(QString pname);
    void sshstatus();
    void getrev();
    void getimei();
    void getimsi();
    void getpower();
    void getos();
    void getkernel();
    void deleteSettings(QString);
    void on_tabWidget_route_currentChanged(int index);
    void on_pushButton_ipinfo_clicked();
    void on_checkBox_sship_clicked(bool checked);
    void on_radioButton_masqlan_clicked(bool checked);
    void on_radioButton_masqsub_clicked(bool checked);
    void on_checkBox_forward_stateChanged(int );
    void on_pushButton_rmfport_clicked();
    void on_pushButton_addfport_clicked();
    void on_pushButton_loportdel_clicked();
    void on_pushButton_addloport_clicked();
    void on_pushButton_gen_clicked();
    void on_pushButton_stop_clicked();
    void on_pushButton_start_clicked();
    void write_wall();
    void on_pushButton_loaddnow_clicked();
    void on_pushButton_saveini_clicked();
    void on_pushButton_loadini_clicked();
    void on_pushButton_deleteset_clicked();
    void on_pushButton_gwdel_clicked();
    void on_pushButton_routedefaultdel_clicked();
    void on_pushButton_resetdns_clicked();
    void on_pushButton_wsave_clicked();
    void on_pushButton_wstartstop_clicked();
    void on_pushButton_wadhoc_clicked();
    void on_pushButton_sshstartstop_clicked();
    void on_pushButton_btsave_clicked();
    void on_pushButton_btonoff_clicked();
    void on_pushButton_btstartstop_clicked();
    void on_pushButton_delboot_clicked();
    void on_pushButton_addblackip_clicked();
    void on_pushButton_rmblackip_clicked();
    void on_pushButton_clblackip_clicked();
    void on_pushButton_loadblackip_clicked();
    void on_pushButton_saveblackip_clicked();
    void on_pushButton_addblackip_out_clicked();
    void on_pushButton_rmblackip_out_clicked();
    void on_pushButton_clblackip_out_clicked();
    void on_pushButton_loadblackip_out_clicked();
    void on_pushButton_saveblackip_out_clicked();
    void on_pushButton_addnowblackip_out_clicked();
    void on_checkBox_blacklist_stateChanged(int state);
    void on_checkBox_blacklist_out_stateChanged(int state);
    void on_checkBox_lom_clicked();
    void on_checkBox_lolan_clicked();
    void on_pushButton_addnowblackip_clicked();
    void on_pushButton_bldnsmasq_clicked();
    void on_pushButton_addbldomain_clicked();
    void on_pushButton_rmbldomain_clicked();
    void on_pushButton_clbldomain_clicked();
    void on_pushButton_loadbldomain_clicked();
    void on_pushButton_savebldomain_clicked();
    void on_pushButton_bldnsmasq_restart_clicked();
};

#endif // MAINWINDOW_H
